@@ -126,7 +126,8 @@ class Run(object):
     """
     Track simulation details based on token and URL
     """
-    def __init__(self):
+    def __init__(self, mode='online'):
+        self._mode = mode
         self._name = None
         self._suppress_errors = False
         self._queue_blocking = False
@@ -143,7 +144,6 @@ class Run(object):
         self._url, self._token = get_auth()
         self._headers = {"Authorization": f"Bearer {self._token}"}
         self._simvue = None
-        self._offline = False
 
     def __enter__(self):
         return self
@@ -156,6 +156,9 @@ class Run(object):
         """
         Start a run
         """
+        if self._mode == 'disabled':
+            return True
+
         data = {'name': self._name, 'status': self._status}
         if reconnect:
             data['system'] = get_system()
@@ -167,7 +170,7 @@ class Run(object):
 
         self._metrics_queue = multiprocessing.Manager().Queue(maxsize=self._queue_size)
         self._events_queue = multiprocessing.Manager().Queue(maxsize=self._queue_size)
-        self._worker = Worker(self._metrics_queue, self._events_queue, self._name, self._url, self._headers, self._offline)
+        self._worker = Worker(self._metrics_queue, self._events_queue, self._name, self._url, self._headers, self._mode)
 
         if multiprocessing.current_process()._parent_pid is None:
             self._worker.start()
@@ -183,10 +186,16 @@ class Run(object):
         else:
             logger.error(message)
 
-    def init(self, name=None, metadata={}, tags=[], description=None, folder='/', running=True, offline=False):
+    def init(self, name=None, metadata={}, tags=[], description=None, folder='/', running=True):
         """
         Initialise a run
         """
+        if self._mode not in ('online', 'offline', 'disabled'):
+            self._error('invalid mode specified, must be online, offline or disabled')
+
+        if self._mode == 'disabled':
+            return True
+
         if not name:
             name = randomname.get_name()
 
@@ -203,7 +212,6 @@ class Run(object):
             self._error('metadata must be a dict')
 
         self._name = name
-        self._offline = offline
 
         if running:
             self._status = 'running'
@@ -229,7 +237,7 @@ class Run(object):
         if self._status == 'running':
             data['system'] = get_system()
 
-        self._simvue = Simvue(self._name, self._offline, self._suppress_errors)
+        self._simvue = Simvue(self._name, self._mode, self._suppress_errors)
         if not self._simvue.create_run(data):
             return False
 
@@ -245,14 +253,16 @@ class Run(object):
         """
         return self._name
 
-    def reconnect(self, name, offline=False):
+    def reconnect(self, name):
         """
         Reconnect to a run in the created state
         """
+        if self._mode == 'disabled':
+            return True
+
         self._status = 'running'
-        self._offline = offline
         self._name = name
-        self._simvue = Simvue(self._name, self._offline, self._suppress_errors)
+        self._simvue = Simvue(self._name, self._mode, self._suppress_errors)
         self._start(reconnect=True)
 
     def config(self,
@@ -278,6 +288,9 @@ class Run(object):
         """
         Add/update metadata
         """
+        if self._mode == 'disabled':
+            return True
+
         if not self._name:
             self._error(INIT_MISSING)
             return False
@@ -301,6 +314,9 @@ class Run(object):
         """
         Add/update tags
         """
+        if self._mode == 'disabled':
+            return True
+
         if not self._name:
             self._error(INIT_MISSING)
             return False
@@ -320,6 +336,9 @@ class Run(object):
         """
         Write event
         """
+        if self._mode == 'disabled':
+            return True
+
         if not self._name:
             self._error(INIT_MISSING)
             return False
@@ -354,6 +373,9 @@ class Run(object):
         """
         Write metrics
         """
+        if self._mode == 'disabled':
+            return True
+
         if not self._name:
             self._error(INIT_MISSING)
             return False
@@ -402,6 +424,9 @@ class Run(object):
         """
         Upload file
         """
+        if self._mode == 'disabled':
+            return True
+
         if not self._name:
             self._error(INIT_MISSING)
             return False
@@ -458,6 +483,9 @@ class Run(object):
         """
         Upload a whole directory
         """
+        if self._mode == 'disabled':
+            return True
+
         if not self._name:
             self._error(INIT_MISSING)
             return False
@@ -490,6 +518,9 @@ class Run(object):
         """
         Save the list of files and/or directories
         """
+        if self._mode == 'disabled':
+            return True
+
         for item in items:
             if os.path.isfile(item):
                 self.save(item, category, filetype, preserve_path)
@@ -502,6 +533,9 @@ class Run(object):
         """
         Set run status
         """
+        if self._mode == 'disabled':
+            return True
+
         if not self._name:
             self._error(INIT_MISSING)
             return False
@@ -525,6 +559,9 @@ class Run(object):
         """
         Close the run
         """
+        if self._mode == 'disabled':
+            return True
+
         if not self._name:
             self._error(INIT_MISSING)
             return False
@@ -539,6 +576,9 @@ class Run(object):
         """
         Add metadata to the specified folder
         """
+        if self._mode == 'disabled':
+            return True
+
         if not self._name:
             self._error(INIT_MISSING)
             return False
@@ -586,6 +626,9 @@ class Run(object):
         """
         Creates an alert with the specified name (if it doesn't exist) and applies it to the current run
         """
+        if self._mode == 'disabled':
+            return True
+
         if not self._name:
             self._error(INIT_MISSING)
             return False
